@@ -2,9 +2,16 @@ import sys
 import os
 
 
-# Exception raised when an invalid API call is attempted.
-class ArgsError(Exception):
-    pass
+# Base class for all exceptions raised by the library.
+class ArgsError(Exception): pass
+
+
+# Exception raised when an invalid name is used in an API call.
+class InvalidName(ArgsError): pass
+
+
+# Exception raised when an argument is not a valid unicode string.
+class InvalidUnicode(ArgsError): pass
 
 
 # An ArgParser instance is responsible for registering options and commands
@@ -81,7 +88,7 @@ class ArgParser:
         elif option := self.options.get(name):
             return len(option.values)
         else:
-            raise ArgsError(f"'{name}' is not a recognised flag or option name")
+            raise InvalidName(f"'{name}' is not a recognised flag or option name")
 
     # Returns true if the specified flag or option was found.
     def found(self, name):
@@ -92,14 +99,14 @@ class ArgParser:
         if option := self.options.get(name):
             return option.value
         else:
-            raise ArgsError(f"'{name}' is not a recognised option name")
+            raise InvalidName(f"'{name}' is not a recognised option name")
 
     # Returns the specified option's list of values.
     def values(self, name):
         if option := self.options.get(name):
             return option.values
         else:
-            raise ArgsError(f"'{name}' is not a recognised option name")
+            raise InvalidName(f"'{name}' is not a recognised option name")
 
     # ------------------------------------------------------
     # Parsing machinery.
@@ -194,20 +201,18 @@ class ArgParser:
                     value = stream.next()
                     if not option.try_append_value(value):
                         self.exit_error(f"invalid option value '{value}'")
+                elif len(arg) > 1:
+                    self.exit_error(f"missing argument for '{char}' option in -{arg}")
                 else:
-                    if len(arg) > 1:
-                        self.exit_error(f"missing argument for '{char}' option in -{arg}")
-                    else:
-                        self.exit_error(f"missing argument for -{arg} option")
+                    self.exit_error(f"missing argument for -{arg} option")
             elif char == "h" and self.helptext is not None:
                 self.exit_help()
             elif char == "v" and self.version is not None:
                 self.exit_version()
+            elif len(arg) > 1:
+                self.exit_error(f"'{char}' in -{arg} is not a recognised flag or option name")
             else:
-                if len(arg) > 1:
-                    self.exit_error(f"'{char}' in -{arg} is not a recognised flag or option name")
-                else:
-                    self.exit_error(f"-{arg} is not a recognised flag or option name")
+                self.exit_error(f"-{arg} is not a recognised flag or option name")
 
     # ------------------------------------------------------
     # Utility methods.
@@ -247,21 +252,22 @@ class ArgParser:
         return "\n".join(lines)
 
     # Python doesn't make this easy... By default when we ask for the command line arguments
-    # it hands us a list of boobytrapped "strings" which might explode when we try to use them
+    # it hands us a list of booby-trapped "strings" which might explode when we try to use them
     # because they contain invalid unicode characters smuggled in as "surrogateescapes". This
     # method filters sys.argv and either returns a list of valid Python strings or raises
     # an ArgsError exception.
     def _get_argstrings(self):
         args_as_strs = []
+        fsencoding = sys.getfilesystemencoding()
         for arg_as_bytes in (os.fsencode(arg) for arg in sys.argv[1:]):
             try:
-                args_as_strs.append(arg_as_bytes.decode(encoding=sys.getfilesystemencoding()))
+                args_as_strs.append(arg_as_bytes.decode(encoding=fsencoding))
             except UnicodeError as err:
-                raise ArgsError("argument is not a valid unicode string") from err
+                raise InvalidUnicode("argument is not a valid unicode string") from err
         return args_as_strs
 
     # ------------------------------------------------------
-    # Exit methods.
+    # Exit helpers.
     # ------------------------------------------------------
 
     # Print the parser's help text and exit.
